SignatureAlgorithm

Enum SignatureAlgorithm 

pub enum SignatureAlgorithm {
    RsaPkcs1v15,
    RsaPss,
    Ecdsa,
    EdDsa,
    Dsa,
}
Supported signature algorithms.

Variants



RsaPkcs1v15

RSA with PKCS#1 v1.5 padding



RsaPss

RSA with PSS padding



Ecdsa

Elliptic Curve Digital Signature Algorithm (ECDSA)



EdDsa

EdDSA (Ed25519/Ed448)



Dsa

Digital Signature Algorithm (DSA) - deprecated

Implementations

Source

impl SignatureAlgorithm

pub fn as_str(&self) -> &'static str

Get the string representation of this algorithm.

pub fn min_key_size(&self) -> usize

Get the minimum key size in bits for this algorithm.

pub fn is_secure(&self) -> bool

Check if this algorithm is considered secure for current use.