Module multi_source

Module multi_source 

Multi-source download functionality.

This module provides the ability to download from multiple sources with different strategies for source selection and fallback.

Structs

MultiSourceFetcher
Multi-source fetcher implementation.