pub struct MultiSourceFetcher<C: HttpClient> { /* private fields */ }Expand description
Multi-source fetcher implementation.
Implementations
Sourceimpl<C: HttpClient + 'static> MultiSourceFetcher<C>
impl<C: HttpClient + 'static> MultiSourceFetcher<C>
Sourcepub async fn fetch_multi_source_with_receipt(
&self,
sources: Vec<DownloadSource>,
destination: &Path,
options: MultiSourceOptions,
) -> Result<FetchReceipt>
pub async fn fetch_multi_source_with_receipt( &self, sources: Vec<DownloadSource>, destination: &Path, options: MultiSourceOptions, ) -> Result<FetchReceipt>
Fetch from multiple sources using the specified strategy.
Sourcepub async fn fetch_planned_sources_with_receipt(
&self,
planned: &PlannedSources,
destination: &Path,
options: &FetchOptions,
) -> Result<FetchReceipt>
pub async fn fetch_planned_sources_with_receipt( &self, planned: &PlannedSources, destination: &Path, options: &FetchOptions, ) -> Result<FetchReceipt>
Fetch from a planned source set produced by pulith-source.
Sourcepub async fn fetch_source_spec_with_receipt(
&self,
spec: SourceSpec,
strategy: SelectionStrategy,
destination: &Path,
options: &FetchOptions,
) -> Result<FetchReceipt>
pub async fn fetch_source_spec_with_receipt( &self, spec: SourceSpec, strategy: SelectionStrategy, destination: &Path, options: &FetchOptions, ) -> Result<FetchReceipt>
Plan and fetch a source specification produced by pulith-source.
Sourcepub async fn fetch_requested_resource_with_receipt(
&self,
resource: &RequestedResource,
strategy: SelectionStrategy,
destination: &Path,
options: &FetchOptions,
) -> Result<FetchReceipt>
pub async fn fetch_requested_resource_with_receipt( &self, resource: &RequestedResource, strategy: SelectionStrategy, destination: &Path, options: &FetchOptions, ) -> Result<FetchReceipt>
Plan and fetch sources directly from a requested resource.
Sourcepub async fn fetch_resolved_resource_with_receipt(
&self,
resource: &ResolvedResource,
strategy: SelectionStrategy,
destination: &Path,
options: &FetchOptions,
) -> Result<FetchReceipt>
pub async fn fetch_resolved_resource_with_receipt( &self, resource: &ResolvedResource, strategy: SelectionStrategy, destination: &Path, options: &FetchOptions, ) -> Result<FetchReceipt>
Plan and fetch sources directly from a resolved resource.